@@ -79,7 +79,8 @@ MainWindow::MainWindow(MainWindow *pParent) :
 #endif
 
     qDebug() << "cache location: " << storagePath;
-    QWebSettings::enablePersistentStorage(storagePath);
+    // QWebSettings::enablePersistentStorage(storagePath);
+    QWebSettings::setIconDatabasePath(storagePath);
 
     // disk cache
     // QString storagePath = QWebSettings::offlineWebApplicationCachePath();
@@ -765,6 +766,7 @@ void MainWindow::linkClicked( const QUrl & url ) {
 }
 
 void MainWindow::unsupportedContent(QNetworkReply* pReply) {
+    Q_ASSERT(pReply);
 
     qDebug() << "unsupportedContent: " << pReply->request().url(); // << pReply;
     QList<QByteArray> headerList = pReply->rawHeaderList();
