@@ -1,20 +1,39 @@
+/*
+ * Copyright 2010 Felipe Crochik <foss@crochik.com>
+ * All rights reserved.
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ */
+
 #ifndef MAINWINDOW_H
 #define MAINWINDOW_H
 
 #include <QtGui/QMainWindow>
 #include <QLabel>
 
-#ifdef Q_WS_MAEMO_5
-    #include <QGraphicsWebView>
-    #include "graphicsview.h"
+#include <QGraphicsWebView>
+#include "graphicsview.h"
 
+#ifdef Q_WS_X11 // meego?
+    // ????
+#endif
+
+#ifdef Q_WS_MAEMO_5
     #include "pickselectoraction.h"
 #endif
 
 #include "webview.h"
-#include "errorbox.h"
-#include "toolbar.h"
-#include "minifiedtoolbar.h"
 #include "bookmark.h"
 #include "webpage.h"
 
@@ -39,6 +58,7 @@ public:
     QWebView *getWebView() { return m_pWebView; }
 
 private:
+    void updateTitle();
     void loadSettings();
     void saveSettings();
 
@@ -66,10 +86,6 @@ private:
     bool isAutoRotate();
     void setLandscape(bool landscape=true);
     void setAutoRotate(bool autoRotate=true);
-#else
-    //white overlay behind the error message
-    void showOverlayOnPage();
-    void hideOverlayOnPage();
 #endif
 
 private slots:
@@ -81,6 +97,8 @@ private slots:
     void on_actionBookmarks_triggered();
     void on_actionHome_triggered();
 
+    void onUserAgentChanged(QAction *pAction);
+
     void aboutQt();
     void switchView();
     void setFullScreen(bool full=true);
@@ -102,10 +120,6 @@ private slots:
 #ifdef Q_WS_MAEMO_5
     void orientationChanged();
     void fullscreen_triggered();
-#else
-    //toolbar visibility control
-    void showToolbar();
-    void hideToolbar();
 #endif
 
     //visit url
@@ -117,7 +131,6 @@ private:
     // mainWindow components
     QUrl            m_currentUrl;
     qreal           m_zoomFactor;
-    QLabel          *m_pLoadingLabel;
     QStringList     m_errors;
 
     QList<Bookmark> *m_pBookmarks;
@@ -134,10 +147,6 @@ private:
 #ifdef Q_WS_MAEMO_5
     PickSelectorAction  *m_pUserAgentSelector;
     PickSelectorAction  *m_pOrientationSelector;
-#else
-    ErrorBox* m_pErrorBox;
-    Toolbar* m_pToolbar;
-    MinifiedToolbar* m_pMiniToolbar;
 #endif
 
 };
